@@ -1,9 +1,9 @@
 package Net::GraphSpace;
 use Moose;
-use MooseX::Method::Signatures;
 
-our $VERSION = '0.0006'; # VERSION
+our $VERSION = '0.0007'; # VERSION
 
+use v5.10;
 use JSON qw(decode_json);
 use LWP::UserAgent;
 use Net::GraphSpace::Edge;
@@ -12,8 +12,9 @@ use Net::GraphSpace::Node;
 
 has user     => (is => 'ro', isa => 'Str', required => 1);
 has password => (is => 'ro', isa => 'Str', required => 1);
-has host     => (is => 'ro', isa => 'Str', required => 1);
+has host     => (is => 'ro', isa => 'Str', default => 'graphspace.org');
 has port     => (is => 'ro', isa => 'Str', default => 80);
+has prefix   => (is => 'ro', isa => 'Str', default => '');
 has _ua      => (
     is      => 'ro',
     isa     => 'LWP::UserAgent',
@@ -30,33 +31,54 @@ has _json => (
     is      => 'ro',
     isa     => 'JSON',
     lazy    => 1,
-    default => sub { JSON->new->pretty->convert_blessed->utf8 },
+    default => sub { JSON->new->convert_blessed->utf8 },
 );
 
-method to_json($x) { $self->_json->encode($x) }
+sub to_json { $_[0]->_json->encode($_[1]) }
 
-method gen_url($path) {
-    return sprintf('http://%s:%d%s', $self->host, $self->port, $path);
+sub gen_url {
+    my ($self, $path) = @_;
+    my ($host, $port, $prefix) = ($self->host, $self->port, $self->prefix);
+    s{^/}{}, s{/$}{} foreach ($prefix, $path);
+    return "http://$host:$port/$prefix/$path";
 }
 
-method add_graph(Net::GraphSpace::Graph $graph) {
+sub add_graph {
+    my ($self, $graph, $graph_id, %args) = @_;
+    my $check = $args{check} // 1;
+
     my $user = $self->user;
-    my $url = $self->gen_url("/api/users/$user/graphs");
-    my $res = $self->_ua->post($url, Content => $self->to_json($graph));
+    my $res;
+    if (defined $graph_id) {
+        if ($check) {
+            die "ERROR: Graph [$graph_id] already exists"
+                if $self->get_graph($graph_id);
+        }
+        my $url = $self->gen_url("/api/users/$user/graphs/$graph_id");
+        my $req = HTTP::Request->new(PUT => $url, [], $self->to_json($graph));
+        $res = $self->_ua->request($req);
+    } else {
+        my $url = $self->gen_url("/api/users/$user/graphs");
+        $res = $self->_ua->post($url, Content => $self->to_json($graph));
+    }
     die msg_from_res($res) unless $res->is_success;
     return decode_json($res->content);
 }
 
-method get_graph(Str $graph_id) {
+sub get_graph {
+    my ($self, $graph_id) = @_;
+
     my $user = $self->user;
     my $url = $self->gen_url("/api/users/$user/graphs/$graph_id");
     my $res = $self->_ua->get($url);
-    #die msg_from_res($res) unless $res->is_success;
-    return undef unless $res->is_success;
+    return undef if $res->code == 404;
+    die msg_from_res($res) unless $res->is_success;
     return Net::GraphSpace::Graph->new_from_http_response($res);
 }
 
-method set_graph(Net::GraphSpace::Graph $graph, Str $graph_id) {
+sub update_graph {
+    my ($self, $graph, $graph_id) = @_;
+
     my $user = $self->user;
     my $url = $self->gen_url("/api/users/$user/graphs/$graph_id");
     my $req = HTTP::Request->new(PUT => $url, [], $self->to_json($graph));
@@ -65,7 +87,9 @@ method set_graph(Net::GraphSpace::Graph $graph, Str $graph_id) {
     return decode_json($res->content);
 }
 
-method delete_graph(Str $graph_id) {
+sub delete_graph {
+    my ($self, $graph_id) = @_;
+
     my $user = $self->user;
     my $url = $self->gen_url("/api/users/$user/graphs/$graph_id");
     my $req = HTTP::Request->new(DELETE => $url);
@@ -93,7 +117,7 @@ Net::GraphSpace - API bindings for GraphSpace
 
 =head1 VERSION
 
-version 0.0006
+version 0.0007
 
 =head1 SYNOPSIS
 
@@ -117,7 +141,7 @@ version 0.0006
 
     # Upload graph to server and set the graph id
     my $graph_id = 'graph-id-1';
-    my $data = $client->set_graph($graph, $graph_id);
+    my $data = $client->add_graph($graph, $graph_id);
     my $url = $data->{url};
 
     # Upload graph to server and have server autogenerate the graph id
@@ -130,7 +154,7 @@ version 0.0006
     $graph = $clent->get_graph($graph_id)
         or die "Could not find graph $graph_id";
     $graph->tags(['foo', 'bar']);
-    $client->set_graph($graph, $graph_id);
+    $client->update_graph($graph, $graph_id);
 
     # Delete a graph
     try {
@@ -156,42 +180,60 @@ Required:
 
 =item password
 
-=item host
-
 =back
 
 Optional:
 
 =over
 
+=item host
+
+Defaults to 'graphspace.org'.
+
 =item port
 
 Defaults to 80.
 
+=item prefix
+
+Defaults to ''.
+Set this if GraphSpace is not hosted at the root of your server.
+For example, if GraphSpace is hosted at http://myserver.com/gs,
+then set C<prefix =E<gt> '/gs'>.
+
 =back
 
 =head1 METHODS
 
-=head2 new(%params)
+=head2 new
+
+    $client = Net::GraphSpace->new(user => 'bob', password => 'secret');
 
 Takes key/value arguments corresponding to the attributes above.
 
-=head2 get_graph($graph_id)
+=head2 get_graph
+
+    $graph = $clent->get_graph($graph_id)
 
 Returns a Net::GraphSpace::Graph object for the given $graph_id.
 Returns undef if the graph could not be found.
 
-=head2 set_graph($graph, $graph_id)
+=head2 add_graph
 
-Creates or updates the graph on the server with id $graph_id.
-Returns a hashref just like add_graph().
-Dies on server error.
-
-=head2 add_graph($graph)
+    $data = $client->add_graph($graph);
+    $data = $client->add_graph($graph, $graph_id);
+    $data = $client->add_graph($graph, $graph_id, check => 0);
 
 Takes a Net::GraphSpace::Graph object and uploads it.
-Use this method only if you don't care what id is assigned to your graph.
-Otherwise, use set_graph to create your graph.
+If $graph_id is not provided, an id is autogenerated for you by the server.
+An optional named paramter $check defaults to 1.
+This means that an extra check is made to see if the graph with the given
+$graph_id already exists on the server.
+An exception is thrown if it is found.
+Set $check => 0 if you don't want this check.
+This will result in greater efficiency, since one less http request is made to
+the server.
+Also, if the graph already exists, it will get overwritten as if update_graph() was called.
 Returns a hashref of the form:
 
     {
@@ -202,8 +244,18 @@ Returns a hashref of the form:
 The url is the location where the graph can be viewed.
 Dies on server error.
 
+=head2 update_graph
+
+    $data = $client->update_graph($graph, $graph_id);
+
+Updates the graph on the server with id $graph_id.
+Returns a hashref just like add_graph().
+Dies on server error.
+
 =head2 delete_graph($graph_id)
 
+    $success = $client->delete_graph($graph, $graph_id);
+
 Deletes the graph with id $graph_id.
 Returns a true value on success.
 Dies on failure or if the graph didn't exist.
