@@ -5,13 +5,14 @@ use Net::GraphSpace::Types;
 
 with 'Net::GraphSpace::AttributesToJSON';
 
-has id       => (is => 'ro', isa => 'Str', required => 1);
-has label    => (is => 'rw', isa => 'Str');
-has popup    => (is => 'rw', isa => 'Str');
-has color    => (is => 'rw', isa => 'Str');
-has size     => (is => 'rw', isa => 'Num');
-has shape    => (is => 'rw', isa => 'Str');
-has graph_id => (is => 'rw', isa => 'Int');
+has id    => (is => 'ro', isa => 'Str', required => 1);
+has label => (is => 'rw', isa => 'Str');
+has popup => (is => 'rw', isa => 'Str');
+has color => (is => 'rw', isa => 'Str');
+has size  => (is => 'rw', isa => 'Num');
+has shape => (is => 'rw', isa => 'Str');
+has graph_id        => (is => 'rw', isa => 'Str');
+has borderWidth     => (is => 'rw', isa => 'Num');
 has labelFontWeight => (is => 'rw', isa => 'LabelFontWeight');
 
 
@@ -26,18 +27,19 @@ Net::GraphSpace::Node
 
 =head1 VERSION
 
-version 0.0006
+version 0.0007
 
 =head1 SYNOPSIS
 
     my $node = Net::GraphSpace::Node->new(
-        id       => 'node-a', # Required
-        label    => 'Node A',
-        popup    => 'stuff that goes in the popup window',
-        color    => '#FF0000',
-        size     => 10.5,
-        shape    => 'RECTANGLE',
-        graph_id => 2,
+        id    => 'node-a', # Required
+        label => 'Node A',
+        popup => 'stuff that goes in the popup window',
+        color => '#FF0000',
+        size  => 10.5,
+        shape => 'RECTANGLE',
+        graph_id        => 'graph22',
+        borderWidth     => 2.5,
         labelFontWeight => 'bold',
     );
 
@@ -72,11 +74,11 @@ Currently, this can contain some html.
 
 =item color
 
-The node color in hex format, e.g., '#F00'.
+The node color in hex format. Example: '#F00' or '#F2F2F2'
 
 =item size
 
-The node size as a floating point value.
+The node size. Example: 10.5
 
 =item shape   
 
@@ -86,7 +88,11 @@ for possible values.
 
 =item graph_id
 
-The integer id of the related graph.
+The id of a related graph. Example: 'graph42'
+
+=item borderWidth
+
+The width of the node border. Example: 2.5
 
 =item labelFontWeight
 
